==> entity_repeat-1.0.0.tar.gz: entity_repeat/src/Plugin/Field/FieldWidget/EntityRepeatWidget.php <==
<?php

namespace Drupal\entity_repeat\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\date_recur_modular\Plugin\Field\FieldWidget\DateRecurModularAlphaWidget as parentAlias;

/**
 * Entity Recur widget.
 *
 * @FieldWidget(
 *   id = "entity_repeat",
 *   label = @Translation("Entity Repeat widget"),
 *   field_types = {
 *     "date_recur",
 *   }
 * )
 */
class EntityRepeatWidget extends parentAlias {
  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state): array {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);

    $entity = $form_state->getformObject()->getEntity();

    // Check user permission to recur.
    if (!_entity_repeat_access($entity)) {
      return $element;
    }

    $element['entity_repeat_enabled'] = [
      '#type' => 'checkbox',
      '#title' => t('Replicate this entity for each of the generated dates'),
    ];

    $element['#theme'] = 'entity_repeat_widget';

    return $element;
  }

  /**
   * Validates the widget.
   *
   * @param array $element
   *   The element.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   * @param array $complete_form
   *   The complete form structure.
   */
  public static function validateModularWidget(array &$element, FormStateInterface $form_state, array &$complete_form): void {
    parent::validateModularWidget($element, $form_state, $complete_form);

    $fieldname = $element['#parents'][0];
    $entity_repeat_enabled = $form_state->getValue($fieldname)[0]['entity_repeat_enabled'];
    if (!$entity_repeat_enabled) {
      return;
    }

    $entity = $form_state->getformObject()->getEntity();
    $entity->data['entity_repeat_enabled'] = 1;

  }
}

==> entity_repeat-1.0.1.tar.gz: entity_repeat/src/Plugin/Field/FieldWidget/EntityRepeatWidget.php <==
<?php

namespace Drupal\entity_repeat\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\date_recur_modular\Plugin\Field\FieldWidget\DateRecurModularAlphaWidget as parentAlias;

/**
 * Entity Recur widget.
 *
 * @FieldWidget(
 *   id = "entity_repeat",
 *   label = @Translation("Entity Repeat widget"),
 *   field_types = {
 *     "date_recur",
 *   }
 * )
 */
class EntityRepeatWidget extends parentAlias {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state): array {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);

    $entity = $form_state->getformObject()->getEntity();

    // Check user permission to recur.
    if (!_entity_repeat_access($entity)) {
      return $element;
    }

    $element['entity_repeat_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Replicate this entity for each of the generated dates'),
    ];

    $element['#theme'] = 'entity_repeat_widget';

    return $element;
  }

  /**
   * Validates the widget.
   *
   * @param array $element
   *   The element.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   * @param array $complete_form
   *   The complete form structure.
   */
  public static function validateModularWidget(array &$element, FormStateInterface $form_state, array &$complete_form): void {
    parent::validateModularWidget($element, $form_state, $complete_form);

    $fieldname = $element['#parents'][0];
    $entity_repeat_enabled = $form_state->getValue($fieldname)[0]['entity_repeat_enabled'];
    if (!$entity_repeat_enabled) {
      return;
    }

    $entity = $form_state->getformObject()->getEntity();
    $entity->data['entity_repeat_enabled'] = 1;

  }

}
